@@ -5,7 +5,7 @@ from bravado.requests_client import RequestsClient as rc
 from bravado.client import SwaggerClient as sc
 
 from upbit.authentication import APIKeyAuthenticator
-from upbit.utils import FutureExtractor
+from upbit.utils import HTTPFutureExtractor
 
 
 HOST = "https://api.upbit.com"
@@ -66,8 +66,8 @@ class APIKey(Base):
         
         ## API 키 목록 및 만료 일자를 조회합니다.
         """
-        result = self.client.APIKey.APIKey_info()
-        return FutureExtractor.future_extraction(result)
+        future = self.client.APIKey.APIKey_info()
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Account(Base):
@@ -84,8 +84,8 @@ class Account(Base):
         
         ## 내가 보유한 자산 리스트를 보여줍니다.
         """
-        result = self.client.Account.Account_info()
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Account.Account_info()
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Account_wallet(self) -> dict:
         """
@@ -98,8 +98,8 @@ class Account(Base):
         입출금 현황 API에서 제공하는 입출금 상태, 블록 상태 정보는 수 분 정도 지연되어 반영될 수 있습니다.
         본 API는 참고용으로만 사용하시길 바라며 실제 입출금을 수행하기 전에는 반드시 업비트 공지사항 및 입출금 현황 페이지를 참고해주시기 바랍니다.
         """
-        result = self.client.Account.Account_wallet()
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Account.Account_wallet()
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Candle(Base):
@@ -131,8 +131,8 @@ class Candle(Base):
         :param count: 캔들 개수 (최대 200개까지 요청 가능) (optional)
         :type count: number
         """
-        result = self.client.Candle.Candle_minutes(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Candle.Candle_minutes(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Candle_days(self, **kwargs) -> dict:
         """
@@ -157,8 +157,8 @@ class Candle(Base):
         현재는 원화(`KRW`) 로 변환하는 기능만 제공하며 추후 기능을 확장할 수 있습니다. (Default: KRW) (optional)
         :type convertingPriceUnit: str
         """
-        result = self.client.Candle.Candle_days(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Candle.Candle_days(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Candle_weeks(self, **kwargs) -> dict:
         """
@@ -177,8 +177,8 @@ class Candle(Base):
         :param count: 캔들 개수 (optional)
         :type count: number
         """
-        result = self.client.Candle.Candle_weeks(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Candle.Candle_weeks(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Candle_month(self, **kwargs) -> dict:
         """
@@ -197,8 +197,8 @@ class Candle(Base):
         :param count: 캔들 개수 (optional)
         :type count: number
         """
-        result = self.client.Candle.Candle_month(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Candle.Candle_month(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Deposit(Base):
@@ -222,8 +222,8 @@ class Deposit(Base):
         :param currency: Currency symbol
         :type currency: str
         """
-        result = self.client.Deposit.Deposit_coin_address(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Deposit.Deposit_coin_address(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Deposit_coin_addresses(self) -> dict:
         """
@@ -234,8 +234,8 @@ class Deposit(Base):
 
         입금 주소 생성 요청 이후 아직 발급되지 않은 상태일 경우 deposit_address가 null일 수 있습니다.
         """
-        result = self.client.Deposit.Deposit_coin_addresses()
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Deposit.Deposit_coin_addresses()
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Deposit_generate_coin_address(self, **kwargs) -> dict:
         """
@@ -255,8 +255,8 @@ class Deposit(Base):
         :param currency: Currency 코드
         :type currency: string
         """
-        result = self.client.Deposit.Deposit_generate_coin_address(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Deposit.Deposit_generate_coin_address(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Deposit_info(self, **kwargs) -> dict:
         """
@@ -273,8 +273,8 @@ class Deposit(Base):
         :param currency: Currency 코드 (optional)
         :type currency: string
         """
-        result = self.client.Deposit.Deposit_info(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Deposit.Deposit_info(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Deposit_info_all(self, **kwargs) -> dict:
         """
@@ -311,8 +311,8 @@ class Deposit(Base):
         - desc : 내림차순 (default)
         :type order_by: str
         """
-        result = self.client.Deposit.Deposit_info_all(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Deposit.Deposit_info_all(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Market(Base):
@@ -332,8 +332,8 @@ class Market(Base):
         :param isDetails: 유의종목 필드과 같은 상세 정보 노출 여부(선택 파라미터)(Default: False) (optional)
         :type isDetails: bool
         """
-        result = self.client.Market.Market_info_all(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Market.Market_info_all(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Order(Base):
@@ -352,8 +352,8 @@ class Order(Base):
 
         :param markets: 마켓 코드 목록 (ex. [KRW-BTC, KRW-ADA])
         """
-        result = self.client.Order.Order_orderbook(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_orderbook(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Order_chance(self, **kwargs) -> dict:
         """
@@ -363,8 +363,8 @@ class Order(Base):
 
         :param market: Market ID
         """
-        result = self.client.Order.Order_chance(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_chance(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
     
     def Order_info(self, **kwargs):
         """
@@ -380,8 +380,8 @@ class Order(Base):
         :param identifier: 조회용 사용자 지정 값 (optional)
         :type identifier: str
         """
-        result = self.client.Order.Order_info(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_info(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
     
     def Order_info_all(self, **kwargs) -> dict:
         """
@@ -418,8 +418,8 @@ class Order(Base):
         - desc : 내림차순 (default)
         :type order_by: str
         """
-        result = self.client.Order.Order_info_all(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_info_all(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
     
     def Order_new(self, **kwargs) -> dict:
         """
@@ -468,8 +468,8 @@ class Order(Base):
         :param identifier: 조회용 사용자 지정값 (선택) (optional)
         :type identifier: str
         """
-        result = self.client.Order.Order_new(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_new(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
     
     def Order_cancel(self, **kwargs) -> dict:
         """
@@ -485,8 +485,8 @@ class Order(Base):
         :param identifier: 조회용 사용자 지정 값 (optional)
         :type identifier: string
         """
-        result = self.client.Order.Order_cancel(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Order.Order_cancel(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Trade(Base):
@@ -508,8 +508,8 @@ class Trade(Base):
         :param markets: 반점으로 구분되는 마켓 코드 (ex. KRW-BTC, BTC-BCC)
         :type markets: str
         """
-        result = self.client.Trade.Trade_ticker(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Trade.Trade_ticker(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Trade_ticks(self, **kwargs) -> dict:
         """
@@ -537,8 +537,8 @@ class Trade(Base):
         비워서 요청 시 가장 최근 체결 날짜 반환. (범위: 1 ~ 7) (optional)
         :type daysAgo: number
         """
-        result = self.client.Trade.Trade_ticks(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Trade.Trade_ticks(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
 
 class Withdraw(Base):
@@ -555,8 +555,8 @@ class Withdraw(Base):
         :param currency: Currency Symbol
         :type currency: str
         """
-        result = self.client.Withdraw.Withdraw_chance(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Withdraw.Withdraw_chance(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Withdraw_coin(self, **kwargs) -> dict:
         """
@@ -586,8 +586,8 @@ class Withdraw(Base):
         - internal : 바로출금
         :type transaction_type: str
         """
-        result = self.client.Withdraw.Withdraw_coin(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Withdraw.Withdraw_coin(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Withdraw_info(self, **kwargs) -> dict:
         """
@@ -604,8 +604,8 @@ class Withdraw(Base):
         :param currency: Currency 코드 (optional)
         :type currency: str
         """
-        result = self.client.Withdraw.Withdraw_info(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Withdraw.Withdraw_info(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Withdraw_info_all(self, **kwargs) -> dict:
         """
@@ -644,8 +644,8 @@ class Withdraw(Base):
         - desc : 내림차순 (default)
         :type order_by: str
         """
-        result = self.client.Withdraw.Withdraw_info_all(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Withdraw.Withdraw_info_all(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
 
     def Withdraw_krw(self, **kwargs) -> dict:
         """
@@ -656,5 +656,5 @@ class Withdraw(Base):
         :param amount: 출금 원화 수량
         :type amount: str
         """
-        result = self.client.Withdraw.Withdraw_krw(**kwargs)
-        return FutureExtractor.future_extraction(result)
+        future = self.client.Withdraw.Withdraw_krw(**kwargs)
+        return HTTPFutureExtractor.future_extraction(future)
